@@ -1,7 +1,7 @@
 #' Row-wise tibble creation
 #'
 #' @description
-#' \lifecycle{maturing}
+#' `r lifecycle::badge("maturing")`
 #'
 #' Create [tibble]s using an easier to read row-by-row layout.
 #' This is useful for small tables of data where readability is
@@ -40,7 +40,7 @@ tribble <- function(...) {
 #' Row-wise matrix creation
 #'
 #' @description
-#' \lifecycle{maturing}
+#' `r lifecycle::badge("maturing")`
 #'
 #' Create matrices laying out the data in rows, similar to
 #' `matrix(..., byrow = TRUE)`, with a nicer-to-read syntax.
@@ -138,6 +138,7 @@ turn_frame_data_into_tibble <- function(names, rest) {
   nrow <- length(rest) / length(names)
   dim(rest) <- c(length(names), nrow)
   dimnames(rest) <- list(names, NULL)
+
   frame_mat <- t(rest)
   frame_col <- turn_matrix_into_column_list(frame_mat)
 
@@ -152,10 +153,11 @@ turn_matrix_into_column_list <- function(frame_mat) {
   for (i in seq_len(ncol(frame_mat))) {
     col <- frame_mat[, i]
 
-    if (!some(col, needs_list_col) && inherits(col, "list")) {
-      # Assign names for somewhat nice error message, remove later
-      names(col) <- rep_along(col, names(frame_col)[[i]])
-      col <- unname(vec_c(!!! col))
+    if (inherits(col, "list") && !some(col, needs_list_col)) {
+      subclass_tribble_c_errors(
+        names(frame_col)[[i]],
+        col <- vec_c(!!! unname(col))
+      )
     }
 
     frame_col[[i]] <- unname(col)
@@ -176,6 +178,16 @@ turn_frame_data_into_frame_matrix <- function(names, rest) {
   frame_mat
 }
 
+subclass_tribble_c_errors <- function(name, code) {
+  withCallingHandlers(
+    code,
+
+    vctrs_error = function(cnd) {
+      cnd_signal(error_tribble_c(name, cnd))
+    }
+  )
+}
+
 # Errors ------------------------------------------------------------------
 
 error_tribble_needs_columns <- function() {
@@ -211,3 +223,9 @@ error_frame_matrix_list <- function(pos) {
     pluralise_commas("Found list-valued element(s) at position(s) ", pos, ".")
   ))
 }
+
+error_tribble_c <- function(name, cnd) {
+  cnd$message <- paste0("Can't create column ", tick(name), ": ", cnd_header(cnd))
+  cnd$class <- c(tibble_error_class("tribble_c"), class(cnd))
+  cnd
+}
