@@ -122,7 +122,7 @@ test_that("[.tbl_df is careful about column indexes (#83)", {
     )
     expect_error(
       foo[c(-1, NA)],
-      class = "tibble_error_na_column_index"
+      class = "vctrs_error_subscript_type"
     )
 
     expect_error(
@@ -167,7 +167,7 @@ test_that("[.tbl_df is careful about column flags (#83)", {
     )
     expect_error(
       foo[array(TRUE, dim = c(1, 1, 1))],
-      "."
+      class = "vctrs_error_subscript_type"
     )
   })
 })
@@ -392,6 +392,36 @@ test_that("can use two-dimensional indexing with matrix and data frame columns (
   expect_identical(df[[1, "z"]], df[1, ]$z)
 })
 
+test_that("can use classed character indexes (#778)", {
+  df <- tibble::tibble(a = 1:3, b = LETTERS[1:3])
+
+  expect_identical(df[mychr(letters[1:2])], df)
+  expect_identical(df[[mychr("a")]], df[["a"]])
+  expect_null(df[[mychr("c")]])
+
+  expect_silent(df[mychr(letters[1:2])] <- df)
+  expect_silent(df[[mychr("c")]] <- 1)
+  expect_silent(df[[mychr("a")]] <-  df[["a"]])
+})
+
+test_that("can use classed integer indexes (#778)", {
+  df <- tibble::tibble(a = 1:3, b = LETTERS[1:3])
+
+  expect_identical(df[myint(1:3), myint(1:2)], df)
+  expect_identical(df[[myint(2)]], df[[2]])
+
+  expect_silent(df[mylgl(TRUE), ] <- df)
+  expect_silent(df[[myint(2)]] <- df[[2]])
+  expect_silent(df[[myint(3)]] <- 1)
+})
+
+test_that("can use classed logical indexes (#778)", {
+  df <- tibble::tibble(a = 1:3, b = LETTERS[1:3])
+
+  expect_identical(df[mylgl(TRUE), mylgl(TRUE)], df)
+  expect_silent(df[mylgl(TRUE), mylgl(TRUE)] <- df)
+})
+
 # $ -----------------------------------------------------------------------
 
 test_that("$ throws warning if name doesn't exist", {
@@ -436,6 +466,13 @@ test_that("[[<-.tbl_df can remove columns (#666)", {
   expect_identical(df, tibble(y = 1:2))
 })
 
+test_that("[[<-.tbl_df requires scalar, positive if numeric", {
+  df <- tibble(x = 1:2, y = x)
+  expect_error(df[[c("x", "y")]] <- 1, class = "vctrs_error_subscript_type")
+  expect_error(df[[1:2]] <- 1, class = "vctrs_error_subscript_type")
+  expect_error(df[[-1]] <- 1, class = "vctrs_error_subscript_type")
+})
+
 # [<- ---------------------------------------------------------------------
 
 test_that("[<-.tbl_df can remove columns", {
@@ -789,6 +826,10 @@ verify_output("subsetting.txt", {
   foo[[1:3]]
   foo[[ letters[1:3] ]]
   foo[[TRUE]]
+  foo[[-1]]
+  foo[[1.5]]
+  foo[[3]]
+  foo[[Inf]]
   foo[[mean]]
   foo[[foo]]
 
